@@ -288,6 +288,15 @@ test_that("gauge_avar() gives correct errors", {
                "'split' cannot be NULL unless initial estimator is 'robustified'")
   expect_silent(gauge_avar("normal", 0.01, "robustified", 1, p, NULL))
 
+
+  # expect error if specify saturated, split != 0.5, m >= 1
+  expect_error(gauge_avar("normal", 0.01, "saturated", iteration = 1,
+                          split = 0.3, parameters = p),
+               "No theory for m >= 1 if saturated initial estimator is not split in half")
+  expect_error(gauge_avar("normal", 0.05, "saturated", iteration = 10,
+                          split = 0.3, parameters = p),
+               "No theory for m >= 1 if saturated initial estimator is not split in half")
+
 })
 
 
@@ -343,6 +352,16 @@ test_that("gauge_covar() gives correct errors", {
                "'split' cannot be NULL unless initial estimator is 'robustified'")
   expect_silent(gauge_covar("normal", 0.01, 0.05, "robustified", 1, p, NULL))
 
+  # expect error if specify saturated, split != 0.5, m >= 1
+  expect_error(gauge_covar("normal", 0.01, 0.05, "saturated", iteration = 1,
+                           split = 0.3, parameters = p),
+                           "No theory for m >= 1 if saturated initial estimator is not split in half")
+  expect_error(gauge_covar("normal", 0.01, 0.05, "saturated", iteration = 10,
+                           split = 0.3, parameters = p),
+               "No theory for m >= 1 if saturated initial estimator is not split in half")
+
+
+
 })
 
 test_that("gauge_covar() and gauge_avar() coincide for s=t=c", {
