@@ -736,7 +736,7 @@ test_that("selection_iis() works correctly", {
                               sis = FALSE, tis = FALSE, uis = FALSE,
                               blocks = NULL, ratio.threshold = 0.8,
                               max.block.size = 30, t.pval = gamma,
-                              wald.pval = t.pval, do.pet = FALSE,
+                              wald.pval = gamma, do.pet = FALSE,
                               ar.LjungB = NULL, arch.LjungB = NULL,
                               normality.JarqueB = NULL,
                               info.method = "sc", include.1cut = FALSE,
@@ -800,7 +800,7 @@ test_that("selection_iis() works correctly", {
                               sis = FALSE, tis = FALSE, uis = FALSE,
                               blocks = NULL, ratio.threshold = 0.8,
                               max.block.size = 30, t.pval = gamma,
-                              wald.pval = t.pval, do.pet = FALSE,
+                              wald.pval = gamma, do.pet = FALSE,
                               ar.LjungB = NULL, arch.LjungB = NULL,
                               normality.JarqueB = NULL,
                               info.method = "sc", include.1cut = FALSE,
@@ -870,7 +870,7 @@ test_that("selection_iis() works correctly", {
                               sis = FALSE, tis = FALSE, uis = FALSE,
                               blocks = NULL, ratio.threshold = 0.8,
                               max.block.size = 30, t.pval = gamma,
-                              wald.pval = t.pval, do.pet = FALSE,
+                              wald.pval = gamma, do.pet = FALSE,
                               ar.LjungB = NULL, arch.LjungB = NULL,
                               normality.JarqueB = NULL,
                               info.method = "sc", include.1cut = FALSE,
@@ -939,7 +939,7 @@ test_that("selection_iis() works correctly", {
                               sis = FALSE, tis = FALSE, uis = FALSE,
                               blocks = NULL, ratio.threshold = 0.8,
                               max.block.size = 30, t.pval = gamma,
-                              wald.pval = t.pval, do.pet = FALSE,
+                              wald.pval = gamma, do.pet = FALSE,
                               ar.LjungB = NULL, arch.LjungB = NULL,
                               normality.JarqueB = NULL,
                               info.method = "sc", include.1cut = FALSE,
@@ -993,7 +993,7 @@ test_that("selection_iis() works correctly", {
                               sis = FALSE, tis = FALSE, uis = FALSE,
                               blocks = NULL, ratio.threshold = 0.8,
                               max.block.size = 30, t.pval = 0.001,
-                              wald.pval = t.pval, do.pet = FALSE,
+                              wald.pval = gamma, do.pet = FALSE,
                               ar.LjungB = NULL, arch.LjungB = NULL,
                               normality.JarqueB = NULL,
                               info.method = "sc", include.1cut = FALSE,
@@ -1068,7 +1068,7 @@ test_that("selection_iis() returns correct input errors", {
                               sis = FALSE, tis = FALSE, uis = FALSE,
                               blocks = NULL, ratio.threshold = 0.8,
                               max.block.size = 30, t.pval = gamma,
-                              wald.pval = t.pval, do.pet = FALSE,
+                              wald.pval = gamma, do.pet = FALSE,
                               ar.LjungB = NULL, arch.LjungB = NULL,
                               normality.JarqueB = NULL,
                               info.method = "sc", include.1cut = FALSE,
